package com.usky.vpp.service;

import java.util.Map;

/**
 * 运管平台 UN/DN 对接服务
 */
public interface VppUnDnService {

    Map<String, Object> tokenRequest(Map<String, Object> body);

    Map<String, Object> createRegistration(Map<String, Object> body);

    Map<String, Object> registerReport(Map<String, Object> body);

    Map<String, Object> momentDataReport(Map<String, Object> body);

    Map<String, Object> intervalDataReport(Map<String, Object> body);

    Map<String, Object> poll(Map<String, Object> body);

    Map<String, Object> distributeEvent(Map<String, Object> body);

    Map<String, Object> createOpt(Map<String, Object> body);

    Map<String, Object> createCq(Map<String, Object> body);

    Map<String, Object> createEventResponse(Map<String, Object> body);
}
